@@ -6,7 +6,7 @@ use warnings;
 use Class::AutoAccess;
 use base qw(Class::AutoAccess HTML::Tag);
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 BEGIN {
 	our $class_def	= {
@@ -21,6 +21,8 @@ sub html {
 	my $self		= shift;
 	my $name		= $self->name;
 	my $value		= $self->value;
+
+	$value 			= &_normalize_value($value);
 	my $js			= $HTML::Tag::DATE::js || $self->js;
 	my @js_path_split = split('/',$js);
 	pop @js_path_split;
@@ -66,6 +68,18 @@ sub _random_id {
 	return $ret;
 }
 
+sub _normalize_value {
+	my $value = shift;
+	if ($value eq 'now') {
+		my ($day,$month,$year) = (localtime())[3..5];
+		$year += 1900;
+		$month++; 
+		$month 	= "0$month" if length($month) == 1;
+		$day 		= "0$day" if length($day) == 1;
+		$value 	= "$year-$month-$day";
+	}
+	return $value;
+}
 
 
 1;
